@@ -202,9 +202,11 @@ capplet_activate (Capplet *capplet)
 	entry = CAPPLET_DIR_ENTRY (capplet)->entry;
 
 #warning FIXME: this should probably be root-manager-helper
+#if 0
 	if (!strncmp (entry->exec[0], "gnomecc", strlen ("gnomecc")))
 		capplet_control_launch (entry->exec[2], entry->name);
-	else if (!strncmp (entry->exec[0], "root-manager", strlen ("root-manager")))
+#endif
+	if (!strncmp (entry->exec[0], "root-manager", strlen ("root-manager")))
 		start_capplet_through_root_manager (entry);
 	else
 		gnome_desktop_entry_launch (entry);
@@ -429,14 +431,21 @@ capplet_cancel_cb (GtkWidget *widget, GtkWidget *app)
 GtkWidget *
 capplet_control_launch (const gchar *capplet_name, gchar *window_title)
 {
-	gchar *oaf_iid, *moniker;
-	gchar *tmp, *tmp1;
+	gchar                  *oaf_iid;
+	gchar                  *moniker;
+	gchar                  *tmp;
+	gchar                  *tmp1;
 
-	GtkWidget *app, *control;
-	CORBA_Environment ev;
+	GtkWidget              *app;
+	GtkWidget              *control;
+	GtkWidget              *dialog;
+	CORBA_Environment       ev;
 
-	Bonobo_PropertyControl property_control;
-	Bonobo_Control control_ref;
+	Bonobo_PropertyControl  property_control;
+	Bonobo_Control          control_ref;
+	Bonobo_PropertyBag      pb;
+
+	BonoboControlFrame     *cf;
 
 	g_return_val_if_fail (capplet_name != NULL, NULL);
 
@@ -453,12 +462,19 @@ capplet_control_launch (const gchar *capplet_name, gchar *window_title)
 	property_control = bonobo_get_object (oaf_iid, "IDL:Bonobo/PropertyControl:1.0", &ev);
 	g_free (oaf_iid);
 
-	if (BONOBO_EX (&ev) || property_control == CORBA_OBJECT_NIL) {
+	if (BONOBO_EX (&ev) && !strcmp (ev._repo_id, "IDL:Bonobo/Moniker/InterfaceNotFound:1.0")) {
 		/* Capplet is already running in this case */
 		g_free (moniker);
 		return NULL;
 	}
 
+	if (BONOBO_EX (&ev) || property_control == CORBA_OBJECT_NIL) {
+		dialog = gnome_error_dialog ("Could not load the capplet.");
+		gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+		g_free (moniker);
+		return NULL;
+	}
+
 	control_ref = Bonobo_PropertyControl_getControl (property_control, 0, &ev);
 
 	if (BONOBO_EX (&ev) || control_ref == CORBA_OBJECT_NIL) {
@@ -475,19 +491,28 @@ capplet_control_launch (const gchar *capplet_name, gchar *window_title)
 	if (control == NULL) {
 		g_critical ("Could not create widget from control");
 		gtk_widget_destroy (app);
-		g_free (moniker);
+		bonobo_object_release_unref (property_control, &ev);
 		app = NULL;
 	} else {
 		gtk_box_pack_start (GTK_BOX (GNOME_DIALOG (app)->vbox), control, TRUE, TRUE, 0);
 
-		bonobo_widget_set_property (BONOBO_WIDGET (control), "moniker", moniker, NULL);
+		cf = bonobo_widget_get_control_frame (BONOBO_WIDGET (control));
+		pb = bonobo_control_frame_get_control_property_bag (cf, &ev);
+		bonobo_property_bag_client_set_value_string (pb, "moniker", moniker, &ev);
 
-		gtk_widget_show_all (app);
+		if (BONOBO_EX (&ev)) {
+			dialog = gnome_error_dialog ("Could not load your configuration settings.");
+			gnome_dialog_run_and_close (GNOME_DIALOG (dialog));
+			gtk_widget_destroy (app);
+			bonobo_object_release_unref (property_control, &ev);
+			app = NULL;
+		} else {
+			gnome_dialog_button_connect (GNOME_DIALOG (app), 0, GTK_SIGNAL_FUNC (capplet_ok_cb), app);
+			gnome_dialog_button_connect (GNOME_DIALOG (app), 1, GTK_SIGNAL_FUNC (capplet_cancel_cb), app);
+			gtk_widget_show_all (app);
+		}
 	}
 
-	gnome_dialog_button_connect (GNOME_DIALOG (app), 0, GTK_SIGNAL_FUNC (capplet_ok_cb), app);
-	gnome_dialog_button_connect (GNOME_DIALOG (app), 1, GTK_SIGNAL_FUNC (capplet_cancel_cb), app);
-
 	CORBA_exception_free (&ev);
 	g_free (moniker);
 
